import React, { useEffect, useState } from 'react';
import { useLocation } from 'react-router-dom';
import Post from '../Post.tsx';
import toast, { Toaster } from 'react-hot-toast';

function User() {
    const search = useLocation().search
    const searchParams = new URLSearchParams(search)
    const userId = searchParams.get("userId")
    const [username, setUsername] = useState("Loading");
    const [postsData, setPostsData]: any = useState([]);

    useEffect(() => {
        const fetchPosts = async () => {
            await fetch(`/api/v1/user/posts/${userId}`, {
                method: "GET"
            }).then(response => response.json())
                .then(posts => setPostsData(posts));
        }

        fetchPosts();
    }, [username]);

    useEffect(() => {
        const fetchUsername = async () => {
            await fetch(`/api/v1/user/by-id/${userId}`, {
                method: "GET"
            }).then(async response => {
                if (response.status == 404) {
                    toast("Такой пользователь не существует!", { icon: '❌️' });
                    window.location.href = ".."
                    return;
                }
                return response.json()
            }).then(user => setUsername(user.username))
        }
        fetchUsername();
    }, [userId]);

    const goBack = () => {
        window.location.href=".."
    }

    return (
        <div>
            <h1>{username}</h1>
            <button className="backButton" onClick={goBack}>Назад</button>
            {postsData.map((post) => {
                return Post.PostTag(new Post.Post(post.id, post.authorId, post.type, post.message, post.date));
            })}
            <Toaster />
        </div>
    );
}

export default User;